.. python-pcapng documentation master file, created by
   sphinx-quickstart on Sun Dec 28 16:37:47 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-pcapng's documentation!
#########################################

Contents:

.. toctree::
   :maxdepth: 2

   library-usage
   api/index


Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
